#
# spec file for package php-maxminddb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name    maxminddb

%define flavor php8%{nil}
%if "%{flavor}" == "" || (0%{?suse_version} >= 1550 && "%{flavor}" == "php7")
%define php_name php
ExclusiveArch:  do-not-build
%else
%define php_name %{flavor}
%endif
%if 0%{?suse_version} <= 1500
%define php_extdir  %(%{__php_config} --extension-dir)
%define php_cfgdir  %{_sysconfdir}/%{php_name}/conf.d
%endif

Name:           %{php_name}-%{pkg_name}
Version:        1.12.0
Release:        1.5
Summary:        PHP extension providing access to maxminddb databases
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
URL:            https://pecl.php.net/package/maxminddb
Source0:        https://pecl.php.net/get/maxminddb-%{version}.tgz
Source1:        php-%{pkg_name}-rpmlintrc
BuildRequires:  %{php_name}-devel >= 7.2.0
BuildRequires:  pkgconfig
BuildRequires:  re2c
BuildRequires:  pkgconfig(libmaxminddb)
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}
Provides:       php-%{pkg_name} = %{version}
Obsoletes:      php-%{pkg_name} < %{version}

%description
This extension provides access to maxminddb databases and is
a drop-in replacement for MaxMind\Db\Reader.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
cd ext
export CFLAGS="%{optflags} -fvisibility=hidden"
%{__phpize}
%configure
%make_build

%check
cd ext
%make_build PHP_EXECUTABLE=%{__php} NO_INTERACTION=1 test

%install
cd ext
make DESTDIR=%{buildroot} install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{php_cfgdir}
cat > %{buildroot}%{php_cfgdir}/%{pkg_name}.ini <<EOF
; comment out next line to disable %{pkg_name} extension in php
extension = %{pkg_name}.so
EOF

%files
%defattr(0644,root,root,-)
%license LICENSE
%doc README.md CHANGELOG.md
%config(noreplace) %{php_cfgdir}/%{pkg_name}.ini
%{php_extdir}/%{pkg_name}.so

%changelog
* Tue Dec  3 2024 Arjen de Korte <suse+build@de-korte.org>
- Updated to version 1.12.0
  * Improve the error handling when the user tries to open a directory
    with the pure PHP reader.
  * Improve the typehints on arrays in the PHPDocs.
* Tue Dec  5 2023 Arjen de Korte <suse+build@de-korte.org>
- Updated to version 1.11.1
  * Resolve warnings when compiling the C extension.
  * Fix various type issues detected by PHPStan level.
* Sat Dec 10 2022 Arjen de Korte <suse+build@de-korte.org>
- Remove php7 build for Tumbleweed (PHP 7.4 has reached EOL)
* Tue Nov  9 2021 Arjen de Korte <suse+build@de-korte.org>
- Updated to version 1.11.0
  * Replace runtime define of a constant to facilitate opcache
    preloading.
  * Resolve minor issue found by the Clang static analyzer in the C
    extension.
* Wed Apr 14 2021 Arjen de Korte <suse+build@de-korte.org>
- Updated to version 1.10.1
  * Fix a `TypeError` exception in the pure PHP reader when using large
    databases on 32-bit PHP builds with the `bcmath` extension. Reported
    by dodo1708. GitHub #124.
* Wed Feb 17 2021 Arjen de Korte <suse+build@de-korte.org>
- Use _multibuild to also build for php8
- Use php_cfgdir and php_extdir macros to determine location of files
* Fri Feb 12 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to version 1.10.0
  When using the pure PHP reader, unsigned integers up to PHP_MAX_INT
  will now be integers in PHP rather than strings. Previously integers
  greater than 2^24 on 32-bit platforms and 2^56 on 64-bit platforms
  would be strings due to the use of `gmp` or `bcmath` to decode them.
  Reported by Alejandro Celaya. gh#maxmind/MaxMind-DB-Reader-php#119
* Fri Jan  8 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Using sources from pecl now
- Updated to version 1.9.0
  * Tiny changes, make it buildable on Windows
* Fri Oct  2 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to version 1.8.0
  * Fixes for PHP 8.0
* Tue Aug 11 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to version 1.7.0
  * PHP 7.2 or greater is now required
  * The extension no longer depends on the pure PHP classes ini
    maxmind-db/reader. You can use it independently
  * Type hints have been added to both the pure PHP implementation
    and the extension.
  * The metadata method on the reader now returns a new copy of the
    metadata object rather than the actual object used by the reader.
  * Work around PHP is_readable() bug. Reported by Ben Roberts.
    gh#maxmind/MaxMind-DB-Reader-php#92
  * This is the first release of the extension as a PECL package.
    gh#maxmind/MaxMind-DB-Reader-php#34
* Thu Jan  9 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to version 1.6.0
  * fix for a possible memory corruption in version 1.5.0 and 1.5.1
  * composer.json file now conflicts with all versions of the
    maxminddb C extension less than the Composer version.
- Updated to version 1.5.1
  * Minor performance improvements.
  * Make tests pass with older versions of libmaxminddb
  * Make tests pass with older versions of libmaxminddb
- Updated to version 1.5.0
  * PHP 5.6 or greater is now required.
  * supports for PHP 8
  * new method, getWithPrefixLen, was added to the Reader class
* Wed Jun 19 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to version 1.4.1
  * The maxminddb extension now returns a string when a uint32
    value is greater than LONG_MAX. Previously, the value would
    overflow. This generally only affects 32-bit machines.
  * For uint64 values, the maxminddb extension now returns an
    integer rather than a string when the value is less than or equal
    to LONG_MAX. This more closely matches the behavior of the pure
    PHP reader.
- Updated to version 1.4.0
  * The maxminddb extension now has the arginfo when using reflection.
  * The maxminddb extension now provides MINFO() function that
    displays the extension version and the libmaxminddb version.
  * The maxminddb configure script now uses pkg-config when
    available to get libmaxmindb build info.
  * The pure PHP reader now correctly decodes integers on 32-bit platforms.
    Previously, large integers would overflow.
  * There are small performance improvements for the pure PHP reader.
* Thu May 17 2018 jweberhofer@weberhofer.at
- Initial release 1.3.0
